@@ -9,8 +9,8 @@ logger = get_task_logger(__name__)
 logger.setLevel(logging.INFO)
 
 
-@celery_app.task(name="reports-pdf.scheduler")
-def pdf_report() -> None:
+@celery_app.task(name="reports-pdf-scheduler")
+def reports_pdf_scheduler() -> None:
 
     logger.info("superset_pdf_report started")
     joblist = glob.glob('*.json')
